@@ -27,10 +27,10 @@ If you want to use make a private app, use WWW::Shopify::Private. If you want to
 In order to get a list of all products, we can do the following:
 
 	# Here we instantiate a copy of the public API object, with all the necessary fields.
-	my $SA = new WWW::Shopify::Public($ShopURL, $APIKey, $AccessToken);
+	my $sa = new WWW::Shopify::Public($shop_url, $api_key, $access_token);
 
 	# Here we call get_all, OO style, and specify the entity we want to get.
-	my @Products = $SA->get_all('Product');
+	my @products = $sa->get_all('Product');
 
 In this way, we can get and modify all the different types of shopify stuffs.
 
@@ -38,24 +38,36 @@ If you don't want to be using a public app, and just want to make a private app,
 
 	# Here we instantiate a copy of the private API object this time, which means we don't need an access token, we just need a password.
 	my $sa = new WWW::Shopify::Private($shop_url, $api_key, $password);
-	my @Products = $SA->get_all('Product');
+	my @products = $sa->get_all('Product');
 
 Easy enough.
 
 To insert a Webhook, we'd do the following.
 
 	my $webhook = new WWW::Shopify::Model::Webhook({topic => "orders/create", address => $URL, format => "json"});
-	$SA->create($Webhook);
+	$sa->create($Webhook);
 
 And that's all there is to it. To delete all the webhooks in a store, we'd do:
 
-	my @Webhooks = $SA->get_all('Webhook');
-	for (@Webhooks) {
-		$SA->delete($_);
-	}
+	$sa->delete($_) for ($sa->get_all('Webhook'));
 
 Very easy.
 
+If we want to do something like update an existing product, without getting it, you can simply create a wrapper object to pass to the sub. Let's update a product's title, if all we have
+is the product ID.
+
+	$sa->update(WWW::Shopify::Model::Product->new({ id => $product_id, title => "My New Title!" }));
+
+That'll update the product title.
+
+Now, for another example. Let's say we want to get all products that have the letter "A" in their title, and double the weight of all their variants (randomly). This is also very easy.
+
+	my @products = $sa->get_all("Product");
+	for my $variant (map { $_->variants } grep { $_->title =~ m/A/ } @products) {
+		$variant->weight($variant->weight*2);
+		$sa->update($variant);
+	}
+
 =cut
 
 use strict;
@@ -64,7 +76,7 @@ use LWP::UserAgent;
 
 package WWW::Shopify;
 
-our $VERSION = '0.99999';
+our $VERSION = '1.01';
 
 use WWW::Shopify::Exception;
 use WWW::Shopify::Field;
@@ -190,10 +202,16 @@ sub use_url {
 
 use Devel::StackTrace;
 sub resolve_trailing_url {
-	my ($self, $package, $action, $parent) = @_;
+	my ($self, $package, $action, $parent, $specs) = @_;
+	$package = ref($package) if ref($package);
 	my $method = lc($action) . "_through_parent";
 	if ($package->$method && (!$parent || !$parent->is_shop || $package ne "WWW::Shopify::Model::Metafield")) {
 		die new WWW::Shopify::Exception("Cannot get, no parent specified.") unless $parent;
+		if ($package eq "WWW::Shopify::Model::Metafield" && ref($parent) eq 'WWW::Shopify::Model::Product::Image' && $specs) {
+			$specs->{owner_id} = $parent->id;
+			$specs->{owner_resource} = "product_image";
+			return "/admin/" . $package->plural;
+		}
 		return "/admin/" . $parent->plural . "/" . $parent->id . "/" . $package->plural;
 	}
 	return "/admin/" . $package->plural;
@@ -205,7 +223,7 @@ sub get_all_limit {
 	$specs->{"limit"} = PULLING_ITEM_LIMIT unless exists $specs->{"limit"};
 	return () if ($specs->{limit} == 0);
 	return $self->get_shop if $package->is_shop;
-	my $url = $self->resolve_trailing_url($package, "get", $specs->{parent}) . ".json";
+	my $url = $self->resolve_trailing_url($package, "get", $specs->{parent}, $specs) . ".json";
 	my ($decoded, $response) = $self->use_url('get', $url, $specs);
 	my @return = map { my $object = $package->from_json($_, $self); $object->associated_parent($specs->{parent}); $object; } @{$decoded->{$package->plural}};
 	return @return;
@@ -297,7 +315,7 @@ sub get_count {
 	$package = $self->translate_model($package);
 	$self->validate_item($package);
 	die "Cannot count $package." unless $package->countable();
-	my ($decoded, $response) = $self->use_url('get', $self->resolve_trailing_url($package, "get", $specs->{parent}) . "/count.json", $specs);
+	my ($decoded, $response) = $self->use_url('get', $self->resolve_trailing_url($package, "get", $specs->{parent}, $specs) . "/count.json", $specs);
 	return $decoded->{'count'};
 }
 
@@ -381,7 +399,7 @@ sub create {
 	my $specs = {};
 	my $missing = first { !exists $item->{$_} } $item->creation_minimal;
 	die new WWW::Shopify::Exception("Missing minimal creation member: $missing in " . ref($item)) if $missing;
-	die new WWW::Shopify::Exception(ref($item) . " requires you to login with an admin account.") if $item->needs_login && !$self->logged_in_admin;
+	die new WWW::Shopify::Exception(ref($item) . " requires you to login with an admin account.") if ($item->needs_login && !$item->needs_plus) && !$self->logged_in_admin;
 	$specs = $item->to_json();
 	my ($decoded, $response) = $self->use_url($item->create_method, $self->resolve_trailing_url(ref($item), "create", $item->associated_parent) . ".json", {$item->singular() => $specs}, $item->needs_login);
 	my $element = $decoded->{$item->singular};
@@ -500,7 +518,7 @@ sub login_admin {
 	$self->{last_login_check} = time;
 	$self->{authenticity_token} = $authenticity_token;
 	$res = $self->ua->request(GET "https://" . $self->shop_url . "/admin");
-	die new WWW::Shopify::Exception($res) unless $res->decoded_content =~ m/meta content="(.*?)" name="csrf-token"/;
+	die new WWW::Shopify::Exception($res) unless $res->decoded_content =~ m/meta name="csrf-token" content="(.*?)"/;
 	$self->{authenticity_token} = $1;
 	$ua->default_header('X-CSRF-Token' => $self->{authenticity_token});
 	return 1;
@@ -572,7 +590,7 @@ sub delete_private_app {
 sub validate_item {
 	eval {	die unless $_[1]; $_[1]->is_item; };
 	die new WWW::Shopify::Exception($_[1] . " is not an item!") if ($@);
-	die new WWW::Shopify::Exception($_[1] . " requires you to login with an admin account.") if $_[1]->needs_login && !$_[0]->logged_in_admin;
+	die new WWW::Shopify::Exception($_[1] . " requires you to login with an admin account.") if ($_[1]->needs_login && !$_[1]->needs_plus)  && !$_[0]->logged_in_admin;
 }
 
 
@@ -587,19 +605,24 @@ Gets around the issue that this is not actually exposed to the API.
 
 =cut
 
+use JSON qw(decode_json);
+
 sub upload_files {
 	my ($self, @images) = @_;
 	die new WWW::Shopify::Exception("Uploading files/images requires you to login with an admin account.") unless $self->logged_in_admin;
+	my @returns;
 	foreach my $path (@images) {
 		die new WWW::Shopify::Exception("Unable to determine extension type.") unless $path =~ m/\.(\w{2,4})$/;
-		my $req = POST "https://" . $self->shop_url . "/admin/files.json",
+		my $req = POST "https://" . $self->shop_url . "/admin/settings/files.json",
 			Content_Type => "form-data",
-			Accept => "application/json",
+			Accept => "*/*",
 			Content => [authenticity_token => $self->{authenticity_token}, "file[file]" => [$path]];
 		my $res = $self->ua->request($req);
+		print STDERR Dumper($res) if $ENV{'SHOPIFY_LOG'} && $ENV{'SHOPIFY_LOG'} == 2;
 		die new WWW::Shopify::Exception("Error uploading $path.") unless $res->is_success;
+		push(@returns, WWW::Shopify::Model::File->from_json(decode_json($res->decoded_content)->{file}));
 	}
-	return int(@images);
+	return @returns;
 }
 
 =cut
