@@ -15,6 +15,7 @@ BEGIN { $fields = {
 	"body" => new WWW::Shopify::Field::String(),
 	"created_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
 	"message" => new WWW::Shopify::Field::String::Words(),
+	"author" => new WWW::Shopify::Field::String(),
 	"subject_id" => new WWW::Shopify::Field::Identifier(),
 	"subject_type" => new WWW::Shopify::Field::String::Enum([qw(Article Blog Collection Comment Order Page Product)]),
 	"verb" => new WWW::Shopify::Field::String()
@@ -30,11 +31,8 @@ my $queries; sub queries { return $queries; }
 BEGIN { $queries = {
 	created_at_min => new WWW::Shopify::Query::LowerBound('created_at'),
 	created_at_max => new WWW::Shopify::Query::UpperBound('created_at'),
-	updated_at_min => new WWW::Shopify::Query::LowerBound('updated_at'),
-	updated_at_max => new WWW::Shopify::Query::UpperBound('updated_at'),
-	status => new WWW::Shopify::Query::Enum('status', ['open', 'closed', 'cancelled', 'any']),
-	financial_status => new WWW::Shopify::Query::Match('financial_status'),
-	fulfillment_status => new WWW::Shopify::Query::Match('fulfillment_status'),
+	filter => new WWW::Shopify::Query::Enum('subject_type', $fields->{subject_type}->values),
+	verb => new WWW::Shopify::Query::Match('verb'),
 	since_id => new WWW::Shopify::Query::LowerBound('id')
 }; }
 
