@@ -17,8 +17,6 @@ BEGIN { $fields = {
 	"customer_id" => new WWW::Shopify::Field::Relation::ReferenceOne("WWW::Shopify::Model::Customer"),
 	"disabled_at" => new WWW::Shopify::Field::Date(),
 	"expires_on" => new WWW::Shopify::Field::Date(),
-	"events" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Event"),
-	"shares" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Event"),
 	"id" => new WWW::Shopify::Field::Identifier(),
 	"initial_value" => new WWW::Shopify::Field::Money(),
 	"line_item_id" => new WWW::Shopify::Field::Relation::ReferenceOne("WWW::Shopify::Model::Order::LineItem"),
@@ -39,6 +37,7 @@ sub get_fields { return grep { $_ ne "code" } keys(%{$_[0]->fields}); }
 sub actions { return qw(disable enable); }
 
 sub needs_login { return 1; }
+sub needs_plus { return 1; }
 
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
