@@ -26,6 +26,9 @@ sub update_fields { return qw(handle title links); }
 sub update_filled { return qw(); }
 
 sub needs_login { return 1; }
+# Shopify recently just killed all their JSON apis for non-api stuff. Why? Who knows?
+# They're just delaying the inevitable.
+sub needs_form_encoding_create { return 1; }
 
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
