@@ -17,6 +17,9 @@ BEGIN { $fields = {
 	"status" => new WWW::Shopify::Field::String::Enum(["success", "failure"]),
 	"tracking_company" => new WWW::Shopify::Field::String(),
 	"tracking_number" => new WWW::Shopify::Field::String(),
+	"tracking_numbers" => new WWW::Shopify::Field::Freeform(),
+	"tracking_url" => new WWW::Shopify::Field::String::URL(),
+	"tracking_urls" => new WWW::Shopify::Field::Freeform(),
 	"updated_at" => new WWW::Shopify::Field::Date(),
 	"receipt" => new WWW::Shopify::Field::Relation::OwnOne('WWW::Shopify::Model::Order::Fulfillment::Receipt'),
 	"line_items" => new WWW::Shopify::Field::Relation::Many('WWW::Shopify::Model::Order::Fulfillment::LineItem', 1),
@@ -30,8 +33,8 @@ sub write_scope { return "write_orders"; }
 
 sub parent { return 'WWW::Shopify::Model::Order'; }
 
-# This is actually required, even if it's null.
-sub creation_minimal { return qw(tracking_number); }
+# Can be tracking number or tracking numbers.
+#sub creation_minimal { return qw(tracking_number); }
 sub creation_filled { return qw(id created_at service status); }
 sub update_filled { return qw(updated_at); }
 
