@@ -21,10 +21,16 @@ BEGIN { $fields = {
 	"gateway" => new WWW::Shopify::Field::String::Enum(["bogus", "real"]),
 	"order_id" => new WWW::Shopify::Field::Relation::Parent('WWW::Shopify::Model::Order'),
 	"test" => new WWW::Shopify::Field::Boolean(),
+	"error_code" => new WWW::Shopify::Field::String(),
+	"signature" => new WWW::Shopify::Field::String(),
+	"source_name" => new WWW::Shopify::Field::String(),
+	"currency" => new WWW::Shopify::Field::String(),
+	"message" => new WWW::Shopify::Field::String(),
+	"payment_details" => new WWW::Shopify::Field::Relation::OwnOne("WWW::Shopify::Model::Transaction::PaymentDetails"),
 	"user_id" => new WWW::Shopify::Field::String(), 
 	"device_id" => new WWW::Shopify::Field::String() };
 }
-sub creation_minimal { return qw(path target); }
+sub creation_minimal { return qw(kind); }
 sub creation_filled { return qw(id created_at); }
 sub update_fields { return qw(amount kind); }
 
